@@ -1,3 +1,3 @@
 from .text_cleaning import *
 from .data_splitting import *
-from .file_parsing import *
\ No newline at end of file
+from .file_processing import *
\ No newline at end of file
